/*
** EXPtype.h -- Explosion Type information for scripts
**
** Copyright 1997 Cavedog Entertainment
*/

#ifndef EXPTYPE_H
#define EXPTYPE_H

/*
Special Effect Particles referenced in the scripting language
with the command emit-sfx.  This file is included by any scripts
that use the command; as well as TAObjScr.cpp in the game; so
it can start the proper effect.
*/

/*
Exploding pieces are activated in the scripting language with
the command "explode".  This file is included by any scripts
that use the command; as well as TAObjScr.cpp in the game; so
it can create the proper effect.
*/

// IMPORTANT:	If you change these defines; copy the file to
//				v:\totala\cdimage\scripts so the scripts have
//				access to the proper data; and recompile them.

const SHATTER=		1;		// The piece will shatter instead of remaining whole
const EXPLODE_ON_HIT=		2;		// The piece will explode when it hits the ground
const FALL=			4;		// The piece will fall due to gravity instead of just flying off
const SMOKE=			8;		// A smoke trail will follow the piece through the air
const FIRE=			16;		// A fire trail will follow the piece through the air
const BITMAPONLY=		32;		// The piece will not fly off or shatter or anything.  Only a bitmap explosion will be rendered.


// Bitmap Explosion Types (these will be changed eventually)

const BITMAP1=			256;
const BITMAP2=			512;
const BITMAP3=			1024;
const BITMAP4=			2048;
const BITMAP5=			4096;
const BITMAPNUKE=		8192;

const BITMAPMASK=		16128;	// Mask of the possible bitmap bits

// Indices for set/get value
const ACTIVATION=			1;	// set or get
const STANDINGMOVEORDERS=	2;	// set or get
const STANDINGFIREORDERS=	3;	// set or get
const HEALTH=			4;	// get (0-100%)
const INBUILDSTANCE=		5;	// set or get
const BUSY=				6;	// set or get (used by misc. special case missions like transport ships)
const PIECE_XZ=			7;	// get
const PIECE_Y=				8;	// get
const UNIT_XZ=				9;	// get
const UNIT_Y=				10;	// get
const UNIT_HEIGHT=			11;	// get
const XZ_ATAN=			12;	// get atan of packed x;z coords
const XZ_HYPOT=			13;	// get hypot of packed x;z coords
const ATAN=				14;	// get ordinary two-parameter atan
const HYPOT=				15;	// get ordinary two-parameter hypot
const GROUND_HEIGHT=		16;	// get
const BUILD_PERCENT_LEFT=	17;	// get 0 = unit is built and ready; 1-100 = How much is left to build
const YARD_OPEN=			18;	// set or get (change which plots we occupy when building opens and closes)
const BUGGER_OFF=			19;	// set or get (ask other units to clear the area)
const ARMORED=				20;	// set or get

#endif // EXPTYPE_H
